package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````@)D$"#0```#LQ0```````#0`(``)
M`"@`)``A``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(%+$`
M`!2Q```%`````!````$```#DO@``Y$X%".1.!0AT`@``P!(```8`````$```
M`@```/B^``#X3@4(^$X%"/@```#X````!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%'E=&0```````````````````````````8`
M```$````4N5T9.2^``#D3@4(Y$X%"!P!```<`0``!`````$```"`%01E````
M````````````````````````*```!````"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@````P````$````%`````,```!'
M3E4`?8L)KKNBKAGR$5=*+X2-(8:)RV0E````3@````@````(`````!`0!"5`
M!("H$0`!HH9!J$````)+*`0I.*(R1XH$#(A.````4```````````````````
M`%,```!5````5@````````!7````6`````````!9````6@```%L`````````
M7````````````````````%T```!@``````````````!A````8P```&0```!F
M`````````&@```!K`````````&T```!N````;P```'``````````R-6R<5GH
M[>SF_S"BSMY'+:/@^TGJT^\.I]VC:R_%F[;;S>.>A_F<@6L)0]8-.I<+Q8D%
MD`T4XIXA_^0.L@&+;\2YG$!K?YI\?ZF<FV[%WQ_9<5@<N^.2?-1DU'RM2^/`
M,F+;[>&G`@IFK\QF8!;)67OP2FOB1\8!0T75[$?L,SI]08[%P^4_+/+;TQWZ
MH6Q@N8WQ#@````````````````````#Z`@`````````````2````2`,`````
M````````$@```+,``````````````!(```"6`P`````````````2````@0,`
M````````````$@```*,!`````````````!(```!\`@`````````````2````
M$P``````````````(````"(``````````````"````"'`P`````````````2
M````CP$`````````````$@```#8$`````````````!(```!P`0``````````
M```2````@@$`````````````$@```&$#`````````````!(````Q`P``````
M```````2````"P,`````````````$@```"X"`````````````!(```#_````
M```````````2````'@(`````````````$@```+(#`````````````!(```#,
M`0`````````````2````&@0`````````````$@```-D"`````````````!(`
M```3`P`````````````2````F@(`````````````$@```.P!````````````
M`!(```"H`0`````````````2````-P(`````````````$@```$`$````````
M`````!(````,!``````````````2````,0$`````````````$@```,T#````
M`````````!(````V```````````````2````U0,`````````````$@```%\!
M`````````````!(```#*```````````````2````^@,`````````````$@``
M`,8#`````````````!(```#S`P`````````````2````JP,`````````````
M$@```'H#`````````````!(````U!0`````````````2````0P$`````````
M````$@```.,#`````````````!(```!>`@`````````````2````6`,`````
M````````$@```.T"`````````````!(```!0`@`````````````2````N0,`
M````````````$@```),"`````````````!(```"M`0`````````````2````
M:0,`````````````$@```,`#`````````````!(```"D`P`````````````2
M````[@``````````````$@```$0``````````````!(```#J`P``````````
M```2````!`0`````````````$@```-D``````````````!(``````@``````
M```````2````AP(`````````````$@```%(!`````````````!(```"/`P``
M```````````2````4`,`````````````$@```/,"`````````````!(````?
M`0`````````````2````10(`````````````$@```%8``````````````!(`
M``"=`P`````````````2````V@$`````````````$@```&4`````````````
M`!(````3!``````````````2````D0``````````````$@```$,#````````
M`````!(```!Z```````````````2````#0$`````````````$@```+D!````
ME00(`````!(```#6!```8-0$"`0````1``\`GP4``*#7!`AN60``$0`/`*D%
M``".O@0(/@<``!(`#0#5!0``1Z,$"!P"```2``T`T`0``##4!`@`````$@`.
M`"X$``!@404(!````"$`&`"H!```2)\$"`T````2``T`;@4``"#3!`AA````
M$@`-`*(```#0E@0(`````!(```!9!0``/%$%"``````0`!<`6P4``#Q1!0@`
M````(``7`"T$``!@404(!````"$`&`#&!```D-,$"`$````2``T`R`4``%6?
M!`B]`@``$@`-`/,$``!CI00(4P```!(`#0`L!```8%$%"`0````1`!@`)P0`
M`!?0!`C5`@``$@`-`",%``!:O`0(.P```!(`#0`^!0``0\<$"&@````2``T`
M8`0``%A1!0@`````$`#Q_VP$``"D804(`````!``\?_=!```N<H$"/($```2
M``T`(@,``&34!`@$````$0`/`%\%``"`F00(`````!(`#0`!!0``39X$"/L`
M```2``T`%P4``$ZB!`CY````$@`-`$H%``!4404(!````!$`%P!L`@``P)8$
M"``````2````N00``!*B!`@\````$@`-`%D$``!8404(`````!``\?^:!0``
M4%$%"`0````1`!<`?@4``%K*!`A?````$@`-`&8%```XF@0(0````!(`#0"E
M`@``9%$%"!,````1`!@`M@4``&>]!`@G`0``$@`-`&@%``!0E`0(`````!(`
M"P``;&EB<&5R;"YS;RXU+C$R+C``7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES
M=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E<FQ?27-T871B=69?<'1R`%!E
M<FQ?<WES7VEN:70S`%!E<FQ?265X:71?9FQA9W-?<'1R`%!E<FQ?<V%V95]D
M97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V7W!T<@!097)L7V%T9F]R:U]L;V-K
M`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R;%]C;VYS=')U8W0`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R<V5R7W!T<@!097)L7V%V7W-H:69T
M`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?271O<%]E;G9?<'1R`%!E<FQ?271A
M:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?;F5W4U9P=@!097)L7VYE
M=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?<'1R`%!E<FQ?26]P7W!T<@!097)L
M7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T
M9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7T=T:')?:V5Y7W!T<@!0
M97)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?27!E<FQ?9&5S=')U8W1?;&5V96Q?
M<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS;RXV`&QI8G!T
M:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&]P96XV-`!?
M7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O+C8`7TE/7W-T
M9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S<')I;G1F`'-T<FYC
M;7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M
M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L
M96X`;65M<V5T`'-T<G-T<@!R;61I<@!M96UC<'D`;W!E;F1I<@!?7V-T>7!E
M7V)?;&]C`&=E='5I9`!R96%D;&EN:P!E>&5C=G``<F5A9&1I<C8T`&UE;6UO
M=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`
M7U]X<W1A=#8T`%]?;'AS=&%T-C0`;&EB8W)Y<'0N<V\N,0!?961A=&$`7U]B
M<W-?<W1A<G0`7V5N9``O=7-R+VQI8B]P97)L-2\U+C$R+C`O:30X-BUP;&0M
M;&EN=7@M=&AR96%D+6UU;'1I+T-/4D4`<&%R7V-U<G)E;G1?97AE8P!P87)?
M8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%]F<%]H=P!84U]);G1E<FYA;'-?
M4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``<VEZ95]L;V%D7VUE7S(`7U]D871A7W-T87)T`'AS7VEN:70`7U]L
M:6)C7V-S=5]I;FET`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!N86UE
M7VQO861?;65?,@!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7V9I;F1P<F]G`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`1TQ)0D-?,BXS`$=,
M24)#7S(N,RXR`$=,24)#7S(N,@!'3$E"0U\R+C`````"``,````#``,`````
M```````#````!````````P`%``8``````````P````,``@`"```````#````
M!``#`````P````<```````0``P`#``,``P`#`````P````,``@````,``P``
M``@``P`#```````#``,````````````#``,`!@`````````#```````#````
M`P`````````!``$``0`!``$``P`!``$````!``$``P`!``$``0`#``$``0`!
M``$``0`!``$``0`!``$``0````$``0`!``$``0````$``0`!``4`&`,``!``
M``!@````%&EI#0``"`#B!0``$````!-I:0T```<`[`4``!````!R&6D)```%
M`/8%```0````$FEI#0``!``"!@``$````!!I:0T```,`#`8````````!``(`
MR0(``!``````````$FEI#0``!@`"!@``$````!!I:0T```(`#`8```````#P
M3P4(!@@``&!1!0@%7@``9%$%"`5P````4`4(!P$```10!0@'`@``"%`%"`<#
M```,4`4(!P0``!!0!0@'!0``%%`%"`<&```84`4(!P<``!Q0!0@'3@``(%`%
M"`<(```D4`4(!PH``"A0!0@'"P``+%`%"`<,```P4`4(!PT``#10!0@'#@``
M.%`%"`</```\4`4(!Q```$!0!0@'$0``1%`%"`<2``!(4`4(!Q,``$Q0!0@'
M%```4%`%"`<5``!44`4(!Q8``%A0!0@'%P``7%`%"`<8``!@4`4(!QD``&10
M!0@'&@``:%`%"`<;``!L4`4(!QP``'!0!0@''0``=%`%"`<>``!X4`4(!Q\`
M`'Q0!0@'(```@%`%"`<A``"$4`4(!R(``(A0!0@'(P``C%`%"`=J``"04`4(
M!U<``)10!0@')```F%`%"`<E``"<4`4(!R8``*!0!0@')P``I%`%"`<H``"H
M4`4(!RD``*Q0!0@'*@``L%`%"`<K``"T4`4(!RP``+A0!0@'+0``O%`%"`<N
M``#`4`4(!R\``,10!0@',```R%`%"`<Q``#,4`4(!S(``-!0!0@',P``U%`%
M"`<T``#84`4(!S4``-Q0!0@'-@``X%`%"`<W``#D4`4(!S@``.A0!0@'.0``
M[%`%"`<Z``#P4`4(!SL``/10!0@'/```^%`%"`<]``#\4`4(!SX```!1!0@'
M/P``!%$%"`=````(404(!T$```Q1!0@'0@``$%$%"`=#```4404(!T0``!A1
M!0@'10``'%$%"`=&```@404(!T<``"11!0@'2```*%$%"`=)```L404(!TH`
M`#!1!0@'2P``-%$%"`=,```X404(!TT``%6)Y5.#[`3H`````%N!PYB[``"+
MD_S___^%TG0%Z)X```#HF04``.B$/P``6%O)P_\U^$\%"/\E_$\%"`````#_
M)0!0!0AH`````.G@_____R4$4`4(:`@```#IT/____\E"%`%"&@0````Z<#_
M____)0Q0!0AH&````.FP_____R404`4(:"````#IH/____\E%%`%"&@H````
MZ9#_____)1A0!0AH,````.F`_____R4<4`4(:#@```#I</____\E(%`%"&A`
M````Z6#_____)210!0AH2````.E0_____R4H4`4(:%````#I0/____\E+%`%
M"&A8````Z3#_____)3!0!0AH8````.D@_____R4T4`4(:&@```#I$/____\E
M.%`%"&AP````Z0#_____)3Q0!0AH>````.GP_O___R5`4`4(:(````#IX/[_
M__\E1%`%"&B(````Z=#^____)4A0!0AHD````.G`_O___R5,4`4(:)@```#I
ML/[___\E4%`%"&B@````Z:#^____)510!0AHJ````.F0_O___R584`4(:+``
M``#I@/[___\E7%`%"&BX````Z7#^____)6!0!0AHP````.E@_O___R5D4`4(
M:,@```#I4/[___\E:%`%"&C0````Z4#^____)6Q0!0AHV````.DP_O___R5P
M4`4(:.````#I(/[___\E=%`%"&CH````Z1#^____)7A0!0AH\````.D`_O__
M_R5\4`4(:/@```#I\/W___\E@%`%"&@``0``Z>#]____)810!0AH"`$``.G0
M_?___R6(4`4(:!`!``#IP/W___\EC%`%"&@8`0``Z;#]____)9!0!0AH(`$`
M`.F@_?___R644`4(:"@!``#ID/W___\EF%`%"&@P`0``Z8#]____)9Q0!0AH
M.`$``.EP_?___R6@4`4(:$`!``#I8/W___\EI%`%"&A(`0``Z5#]____):A0
M!0AH4`$``.E`_?___R6L4`4(:%@!``#I,/W___\EL%`%"&A@`0``Z2#]____
M);10!0AH:`$``.D0_?___R6X4`4(:'`!``#I`/W___\EO%`%"&AX`0``Z?#\
M____)<!0!0AH@`$``.G@_/___R7$4`4(:(@!``#IT/S___\ER%`%"&B0`0``
MZ<#\____)<Q0!0AHF`$``.FP_/___R704`4(:*`!``#IH/S___\EU%`%"&BH
M`0``Z9#\____)=A0!0AHL`$``.F`_/___R7<4`4(:+@!``#I</S___\EX%`%
M"&C``0``Z6#\____)>10!0AHR`$``.E0_/___R7H4`4(:-`!``#I0/S___\E
M[%`%"&C8`0``Z3#\____)?!0!0AHX`$``.D@_/___R7T4`4(:.@!``#I$/S_
M__\E^%`%"&CP`0``Z0#\____)?Q0!0AH^`$``.GP^____R4`404(:``"``#I
MX/O___\E!%$%"&@(`@``Z=#[____)0A1!0AH$`(``.G`^____R4,404(:!@"
M``#IL/O___\E$%$%"&@@`@``Z:#[____)111!0AH*`(``.F0^____R48404(
M:#`"``#I@/O___\E'%$%"&@X`@``Z7#[____)2!1!0AH0`(``.E@^____R4D
M404(:$@"``#I4/O___\E*%$%"&A0`@``Z4#[____)2Q1!0AH6`(``.DP^___
M_R4P404(:&`"``#I(/O___\E-%$%"&AH`@``Z1#[____)3A1!0AH<`(``.D`
M^___,>U>B>&#Y/!05%)HD-,$"&@@TP0(459H%]`$".A/_/__])"0D)"0D)"0
MD)"0D)"058GE4X/L!(`]>%$%"`!U/:%\404(N_!.!0B!Z^Q.!0C!^P)+.=AS
M'I"-M"8`````0*-\404(_Q2%[$X%"*%\404(.=ARZL8%>%$%"`%86UW#ZPV0
MD)"0D)"0D)"0D)"058GE@^P(BQ7T3@4(A=)T%K@`````A<!T#8/L#&CT3@4(
M_]"#Q!#)PU6)Y8/L&,=%]&C4!`B#[`QJ`.C!_O__@\00BP"#[`Q0Z*/[__^#
MQ!#_=?1HP)8$"&ARU`0(4.AM_O__@\00R<-5B>53@>PD$```BT4,B87D[___
MBT40B87@[___9:$4````B47T,<"XCM0$"(/L!&C_#P``C97T[___4E#HA_W_
M_X/$$(F%\.___X.]\.___P!^&(N%\.___TB*A`7T[___A,!U!O^-\.___X.]
M\.___P!^68N%\.___X/L!%!J+XV%].___U#HG/W__X/$$(7`=#J+G?#O__^#
M[`QJ`.CU_?__@\00BP"#[`Q0Z-?Z__^#Q!!3C97T[___4O^UY.___U#H(/S_
M_X/$$.LS@^P,:@#HP?W__X/$$(L`@^P,4.BC^O__@\00@^P$_[7@[____[7D
M[___4.AK^O__@\00BT7T93,%%````'0%Z&?\__^+7?S)PU6)Y5=64X/L'(M]
M"(7_=`FA8%$%"(7`=0>X`````.MSB?OK`4.*`X3`=`:*`SP]=?.)VHGXB=$I
MP8E-Y(LU8%$%".M$BT7D@^P$4%=3Z-#\__^#Q!"%P'4LBT7DC00#B@`\/74@
MB?*A8%$%"(G1*<&)R,'X`HG"BT4,B1"+1>1`C00#ZPZ#Q@2+'H7;=;:X````
M`(UE](/$`%M>7UW#58GE@^P8@^P(C47T4/]U".A-____@\00R<-5B>575E.#
M[!R+=0R*!CP]=0%&@^P,5NC.^O__@\00B47D@^P(C47@4/]U".@7____@\00
MB<.%VW0Q@^P,4^BG^O__@\00.T7D#X+4````D(H&B`.*`X3`#Y7`0T:$P'7O
MN`````#I3`$``(L=8%$%"+\`````ZP2#PP1'BP.%P'7VH:!A!0B%P'0RC4<"
MP>`"B<*A8%$%"(/L"%)0Z#CX__^#Q!"C8%$%"*%@404(A<!U6+C_____Z?H`
M``#'!:!A!0@!````C4<"P>`"@^P,4.BT^O__@\00B<.%VW4*N/_____IS@``
M`(GXC12%`````*%@404(@^P$4E!3Z`C[__^#Q!")'6!1!0BA8%$%"(GZ0L'B
M`@'0QP``````B?B)1>"+70CK`4.*`X3`=`:*`SP]=?.A8%$%"(M5X,'B`HT\
M$(G:BT4(B=$IP8G(`T7D@\`"@^P,4.@M^O__@\00B0>+!X7`=0>X_____^M(
MH6!1!0B+5>#!X@(!T(L8ZP%#BT4(B@"(`XH#A,`/E<#_10B$P'0&B@,\/77D
MQ@,]0Y"*!H@#B@.$P`^5P$-&A,!U[[@`````C67T@\0`6UY?7<-5B>53@^P4
MZR&A8%$%"(M5],'B`HT<$(U#!(L`B0.+`X7`=`6#PP3K[I"#[`B-1?10_W4(
MZ$W]__^#Q!"%P'7)BUW\R<-5B>6![!@@``!EH10```")1?0QP,>%[-___P``
M``#H4/;__[JAU`0(:*W4!`A04HV%\^___U#H&/;__X/$$(F%Z-___X.]Z-__
M_P!Y"K@`````Z9$```"-A?/O__^#[`1H`!```(V5\M___U)0Z('Y__^#Q!")
MA>C?__^#O>C?__\`>0>X`````.M=BX7HW___0(/L#%#HZ/C__X/$$(F%[-__
M_X.][-___P!U![@`````ZS2+A>C?__^#[`10C87RW___4/^U[-___^CS]___
M@\00BX7HW___`X7LW___Q@``BX7LW___BU7T93,5%````'0%Z*KX___)PU6)
MY8/L".CZ_O__R<-5B>6![#@0``"+10B)A=3O__^+10R)A=#O__]EH10```")
M1?0QP(/L#&BQU`0(Z*3\__^#Q!")A>CO__^A1%$%"(/L"%#_M=3O___H&_C_
M_X/$$(7`="&#[`C_M=3O__]HNM0$".B'_/__@\00BX74[___Z3("``"#[`S_
MM=3O___H5??__X/$$(F%Y.___Z%(404(@^P(4/^UT.___^@8^/__@\00B87P
M[___Z=`!``"+A?#O__^*`(3`=0K'A?#O___'U`0(@[WH[___`'0Y@^P(_[7P
M[____[7H[___Z/?X__^#Q!"%P'4>H4A1!0B#[`A0:@#HP/?__X/$$(F%\.__
M_^EX`0``@^P,_[7P[___Z,3V__^#Q!")A>SO___K%?^-[.___XN%[.___P.%
M\.___\8``(N%[.___T@#A?#O__^*$*%$404(B@`XPG31BX7L[___0`.%Y.__
M_SW_#P``?B&#[`C_M=3O__]HNM0$".AY^___@\00BX74[___Z20!``"+%411
M!0BXR=0$"(/L#/^UU.___U+_M?#O__]0C87T[___4.B=\___@\0@@^P,:@#H
M`/C__X/$$(L`@^P,4.CB]/__@\00@^P,4.@&]___@\00C97T[___@^P(4%+H
M8S(``(/$$(7`=7F#[`QJ`.C"]___@\00BP"#[`Q0Z*3T__^#Q!"#[`Q0Z,CV
M__^#Q!"+0!`E`/```#T`@```=4.#[`AJ`8V%].___U#HY?3__X/$$(7`=2N#
M[`B-A?3O__]0:+K4!`CHH/K__X/$$(/L#(V%].___U#H2/?__X/$$.M"H4A1
M!0B#[`A0:@#H0_;__X/$$(F%\.___X.]\.___P`/A2/^__^#[`C_M=3O__]H
MNM0$".A0^O__@\00BX74[___BU7T93,5%````'0%Z.#U___)PU6)Y8/L$(M%
M"(E%_(M%"(E%^.L:BT7XBA"A1%$%"(H`.,)U!XM%^$")1?S_1?B+1?B*`(3`
M==V+1?S)PU6)Y5.#[`2#?0@`=`F+10B*`(3`=16#[`QHQ]0$".B/]O__@\00
MZ<D```"#[`S_=0CHK/3__X/$$$B)PP-=".L!2SM="'80BA.A1%$%"(H`.,)T
M[>L!2SM="'8-BA.A1%$%"(H`.,)U[3M="'4RBA.A1%$%"(H`.,)U$H/L#&C'
MU`0(Z"KV__^#Q!#K9Z%$404(@^P,4.@7]O__@\00ZU1+.UT(=@V*$Z%$404(
MB@`XPG3MB=J+10B)T2G!B<B#P`(]`!```'8'N`````#K)8G:BT4(B=$IP8G(
M0(/L!%#_=0AHH%$%".@V\O__@\00N*!1!0B+7?S)PU6)Y5=64X/L/&6A%```
M`(E%Y#'`C47"NGS5!`B[(@```(G!@^$"A<ET#V:+"F:)"(/``H/"`H/K`HG9
MP>D"B<>)UO.EB?*)^+D`````B=Z#Y@*%]G0+9HLT"F:)-`B#P0*#XP&%VW0&
MBA0*B!0(@^P,:-#4!`CH1OK__X/$$(/L#&C@U`0(Z#;Z__^#Q!"#[`QHL=0$
M".@F^O__@\00@^P,:.S4!`CH%OK__X/$$(/L#&CVU`0(Z`;Z__^#Q!"#[`QH
M`-4$".CV^?__@\00@^P,:+K4!`CHYOG__X/$$(/L#&@*U00(Z-;Y__^#Q!"#
M[`QH$]4$".C&^?__@\00@^P,:![5!`CHVO?__X/$$(E%O(-]O`!T$X/L"/]U
MO&CVU`0(Z-CW__^#Q!"#[`QH+]4$".BN]___@\00B46\@WV\`'03@^P(_W6\
M:$'5!`CHK/?__X/$$(/L#&A,U00(Z(+W__^#Q!")1;R#?;P`=!6#[`C_=;QH
ML=0$".B`]___@\00ZV>#[`QH7-4$".A4]___@\00B46\@WV\`'05@^P(_W6\
M:.S4!`CH4O?__X/$$.LYC47"@\`1B46\@^P$:@IH;=4$"/]UO.B<\___@\00
MA<!U%XM%O(/`"H/L"%!H[-0$".@7]___@\00@^P(:'C5!`AHT-0$".@"]___
M@\00BT7D93,%%````'0%Z)CR__^-9?2#Q`!;7E]=PU6)Y8/L&*%,404(@_C_
M=3R#[`QH[-0$".BL]O__@\00B47T@WWT`'09BT7TB@"$P'00BT7TB@`\,'0'
MN`$```#K!;@`````HTQ1!0BA3%$%",G#58GE4X'L<`$``(M%"(/`'(E%],=%
M^`````#K0XM%](L`B47P@T7T!(M%\(G"P>(8BT7PP>`()0``_P`)PHM%\,'H
M""4`_P``"<*+1?#!Z!@)PHM%^(F4A9C^____1?B#??@/?K?'1?@0````ZU^+
M1?B#Z`.+E(68_O__BT7X@^@(BX2%F/[__S'"BT7X@^@.BX2%F/[__S'"BT7X
M@^@0BX2%F/[__S'"BT7XB92%F/[__XM%^(N$A9C^__^)PM'"BT7XB92%F/[_
M__]%^(-]^$]^FXM%"(L`B47LBT4(BT`$B47HBT4(BT`(B47DBT4(BT`,B47@
MBT4(BT`0B47<C868_O__B478BT7LB<'!P06+1>2+5>@APHM%Z/?0(T7@"="-
M!`&)P@-5W(M%V(L`C00"!9EY@EJ)1?"#1=@$P47H'HM%\(G!P<$%BT7HBU7L
M(<*+1>SWT"-%Y`G0C00!B<(#5>"+1=B+`(T$`@69>8):B47<@T78!,%%[!Z+
M1=R)P<'!!8M%[(M5\"'"BT7P]]`C1>@)T(T$`8G"`U7DBT78BP"-!`(%F7F"
M6HE%X(-%V`3!1?`>BT7@B<'!P06+1?"+5=PAPHM%W/?0(T7L"="-!`&)P@-5
MZ(M%V(L`C00"!9EY@EJ)1>2#1=@$P47<'HM%Y(G!P<$%BT7<BU7@(<*+1>#W
MT"-%\`G0C00!B<(#5>R+1=B+`(T$`@69>8):B47H@T78!,%%X!Z+1>B)P<'!
M!8M%X(M5Y"'"BT7D]]`C1=P)T(T$`8G"`U7PBT78BP"-!`(%F7F"6HE%[(-%
MV`3!1>0>BT7LB<'!P06+1>2+5>@APHM%Z/?0(T7@"="-!`&)P@-5W(M%V(L`
MC00"!9EY@EJ)1?"#1=@$P47H'HM%\(G!P<$%BT7HBU7L(<*+1>SWT"-%Y`G0
MC00!B<(#5>"+1=B+`(T$`@69>8):B47<@T78!,%%[!Z+1=R)P<'!!8M%[(M5
M\"'"BT7P]]`C1>@)T(T$`8G"`U7DBT78BP"-!`(%F7F"6HE%X(-%V`3!1?`>
MBT7@B<'!P06+1?"+5=PAPHM%W/?0(T7L"="-!`&)P@-5Z(M%V(L`C00"!9EY
M@EJ)1>2#1=@$P47<'HM%Y(G!P<$%BT7<BU7@(<*+1>#WT"-%\`G0C00!B<(#
M5>R+1=B+`(T$`@69>8):B47H@T78!,%%X!Z+1>B)P<'!!8M%X(M5Y"'"BT7D
M]]`C1=P)T(T$`8G"`U7PBT78BP"-!`(%F7F"6HE%[(-%V`3!1>0>BT7LB<'!
MP06+1>2+5>@APHM%Z/?0(T7@"="-!`&)P@-5W(M%V(L`C00"!9EY@EJ)1?"#
M1=@$P47H'HM%\(G!P<$%BT7HBU7L(<*+1>SWT"-%Y`G0C00!B<(#5>"+1=B+
M`(T$`@69>8):B47<@T78!,%%[!Z+1=R)P<'!!8M%[(M5\"'"BT7P]]`C1>@)
MT(T$`8G"`U7DBT78BP"-!`(%F7F"6HE%X(-%V`3!1?`>BT7@B<'!P06+1?"+
M5=PAPHM%W/?0(T7L"="-!`&)P@-5Z(M%V(L`C00"!9EY@EJ)1>2#1=@$P47<
M'HM%Y(G!P<$%BT7<BU7@(<*+1>#WT"-%\`G0C00!B<(#5>R+1=B+`(T$`@69
M>8):B47H@T78!,%%X!Z+1>B)P<'!!8M%X(M5Y"'"BT7D]]`C1=P)T(T$`8G"
M`U7PBT78BP"-!`(%F7F"6HE%[(-%V`3!1>0>BT7LB<'!P06+1>2+5>@APHM%
MZ/?0(T7@"="-!`&)P@-5W(M%V(L`C00"!9EY@EJ)1?"#1=@$P47H'HM%\(G!
MP<$%BT7HBU7L(<*+1>SWT"-%Y`G0C00!B<(#5>"+1=B+`(T$`@69>8):B47<
M@T78!,%%[!Z+1=R)P<'!!8M%[(M5\#'0,T7HC00!B<(#5>2+1=B+`(T$`@6A
MZ]ENB47@@T78!,%%\!Z+1>")P<'!!8M%\(M5W#'0,T7LC00!B<(#5>B+1=B+
M`(T$`@6AZ]ENB47D@T78!,%%W!Z+1>2)P<'!!8M%W(M5X#'0,T7PC00!B<(#
M5>R+1=B+`(T$`@6AZ]ENB47H@T78!,%%X!Z+1>B)P<'!!8M%X(M5Y#'0,T7<
MC00!B<(#5?"+1=B+`(T$`@6AZ]ENB47L@T78!,%%Y!Z+1>R)P<'!!8M%Y(M5
MZ#'0,T7@C00!B<(#5=R+1=B+`(T$`@6AZ]ENB47P@T78!,%%Z!Z+1?")P<'!
M!8M%Z(M5[#'0,T7DC00!B<(#5>"+1=B+`(T$`@6AZ]ENB47<@T78!,%%[!Z+
M1=R)P<'!!8M%[(M5\#'0,T7HC00!B<(#5>2+1=B+`(T$`@6AZ]ENB47@@T78
M!,%%\!Z+1>")P<'!!8M%\(M5W#'0,T7LC00!B<(#5>B+1=B+`(T$`@6AZ]EN
MB47D@T78!,%%W!Z+1>2)P<'!!8M%W(M5X#'0,T7PC00!B<(#5>R+1=B+`(T$
M`@6AZ]ENB47H@T78!,%%X!Z+1>B)P<'!!8M%X(M5Y#'0,T7<C00!B<(#5?"+
M1=B+`(T$`@6AZ]ENB47L@T78!,%%Y!Z+1>R)P<'!!8M%Y(M5Z#'0,T7@C00!
MB<(#5=R+1=B+`(T$`@6AZ]ENB47P@T78!,%%Z!Z+1?")P<'!!8M%Z(M5[#'0
M,T7DC00!B<(#5>"+1=B+`(T$`@6AZ]ENB47<@T78!,%%[!Z+1=R)P<'!!8M%
M[(M5\#'0,T7HC00!B<(#5>2+1=B+`(T$`@6AZ]ENB47@@T78!,%%\!Z+1>")
MP<'!!8M%\(M5W#'0,T7LC00!B<(#5>B+1=B+`(T$`@6AZ]ENB47D@T78!,%%
MW!Z+1>2)P<'!!8M%W(M5X#'0,T7PC00!B<(#5>R+1=B+`(T$`@6AZ]ENB47H
M@T78!,%%X!Z+1>B)P<'!!8M%X(M5Y#'0,T7<C00!B<(#5?"+1=B+`(T$`@6A
MZ]ENB47L@T78!,%%Y!Z+1>R)P<'!!8M%Y(M5Z#'0,T7@C00!B<(#5=R+1=B+
M`(T$`@6AZ]ENB47P@T78!,%%Z!Z+1?")P<'!!8M%Z(M5[#'0,T7DC00!B<(#
M5>"+1=B+`(T$`@6AZ]ENB47<@T78!,%%[!Z+1=R)P<'!!8M%[(M5\#'0,T7H
MC00!B<(#5>2+1=B+`(T$`@6AZ]ENB47@@T78!,%%\!Z+1>")P<'!!8M%\(M5
MW#'0,T7LC00!B<(#5>B+1=B+`(T$`@6AZ]ENB47D@T78!,%%W!Z+1>2)P\'#
M!8M%\(M5W`G0(T7@BU7PBTW<(<H)T(T$`XG"`U7LBT78BP"-!`(M)$/D<(E%
MZ(-%V`3!1>`>BT7HB</!PP6+1=R+5>`)T"-%Y(M5W(M-X"'*"="-!`.)P@-5
M\(M%V(L`C00"+21#Y'")1>R#1=@$P47D'HM%[(G#P<,%BT7@BU7D"=`C1>B+
M5>"+3>0AR@G0C00#B<(#5=R+1=B+`(T$`BTD0^1PB47P@T78!,%%Z!Z+1?")
MP\'#!8M%Y(M5Z`G0(T7LBU7DBTWH(<H)T(T$`XG"`U7@BT78BP"-!`(M)$/D
M<(E%W(-%V`3!1>P>BT7<B</!PP6+1>B+5>P)T"-%\(M5Z(M-["'*"="-!`.)
MP@-5Y(M%V(L`C00"+21#Y'")1>"#1=@$P47P'HM%X(G#P<,%BT7LBU7P"=`C
M1=R+5>R+3?`AR@G0C00#B<(#5>B+1=B+`(T$`BTD0^1PB47D@T78!,%%W!Z+
M1>2)P\'#!8M%\(M5W`G0(T7@BU7PBTW<(<H)T(T$`XG"`U7LBT78BP"-!`(M
M)$/D<(E%Z(-%V`3!1>`>BT7HB</!PP6+1=R+5>`)T"-%Y(M5W(M-X"'*"="-
M!`.)P@-5\(M%V(L`C00"+21#Y'")1>R#1=@$P47D'HM%[(G#P<,%BT7@BU7D
M"=`C1>B+5>"+3>0AR@G0C00#B<(#5=R+1=B+`(T$`BTD0^1PB47P@T78!,%%
MZ!Z+1?")P\'#!8M%Y(M5Z`G0(T7LBU7DBTWH(<H)T(T$`XG"`U7@BT78BP"-
M!`(M)$/D<(E%W(-%V`3!1>P>BT7<B</!PP6+1>B+5>P)T"-%\(M5Z(M-["'*
M"="-!`.)P@-5Y(M%V(L`C00"+21#Y'")1>"#1=@$P47P'HM%X(G#P<,%BT7L
MBU7P"=`C1=R+5>R+3?`AR@G0C00#B<(#5>B+1=B+`(T$`BTD0^1PB47D@T78
M!,%%W!Z+1>2)P\'#!8M%\(M5W`G0(T7@BU7PBTW<(<H)T(T$`XG"`U7LBT78
MBP"-!`(M)$/D<(E%Z(-%V`3!1>`>BT7HB</!PP6+1=R+5>`)T"-%Y(M5W(M-
MX"'*"="-!`.)P@-5\(M%V(L`C00"+21#Y'")1>R#1=@$P47D'HM%[(G#P<,%
MBT7@BU7D"=`C1>B+5>"+3>0AR@G0C00#B<(#5=R+1=B+`(T$`BTD0^1PB47P
M@T78!,%%Z!Z+1?")P\'#!8M%Y(M5Z`G0(T7LBU7DBTWH(<H)T(T$`XG"`U7@
MBT78BP"-!`(M)$/D<(E%W(-%V`3!1>P>BT7<B</!PP6+1>B+5>P)T"-%\(M5
MZ(M-["'*"="-!`.)P@-5Y(M%V(L`C00"+21#Y'")1>"#1=@$P47P'HM%X(G#
MP<,%BT7LBU7P"=`C1=R+5>R+3?`AR@G0C00#B<(#5>B+1=B+`(T$`BTD0^1P
MB47D@T78!,%%W!Z+1>2)P\'#!8M%\(M5W`G0(T7@BU7PBTW<(<H)T(T$`XG"
M`U7LBT78BP"-!`(M)$/D<(E%Z(-%V`3!1>`>BT7HB</!PP6+1=R+5>`)T"-%
MY(M5W(M-X"'*"="-!`.)P@-5\(M%V(L`C00"+21#Y'")1>R#1=@$P47D'HM%
M[(G!P<$%BT7DBU7H,=`S1>"-!`&)P@-5W(M%V(L`C00"+2H^G36)1?"#1=@$
MP47H'HM%\(G!P<$%BT7HBU7L,=`S1>2-!`&)P@-5X(M%V(L`C00"+2H^G36)
M1=R#1=@$P47L'HM%W(G!P<$%BT7LBU7P,=`S1>B-!`&)P@-5Y(M%V(L`C00"
M+2H^G36)1>"#1=@$P47P'HM%X(G!P<$%BT7PBU7<,=`S1>R-!`&)P@-5Z(M%
MV(L`C00"+2H^G36)1>2#1=@$P47<'HM%Y(G!P<$%BT7<BU7@,=`S1?"-!`&)
MP@-5[(M%V(L`C00"+2H^G36)1>B#1=@$P47@'HM%Z(G!P<$%BT7@BU7D,=`S
M1=R-!`&)P@-5\(M%V(L`C00"+2H^G36)1>R#1=@$P47D'HM%[(G!P<$%BT7D
MBU7H,=`S1>"-!`&)P@-5W(M%V(L`C00"+2H^G36)1?"#1=@$P47H'HM%\(G!
MP<$%BT7HBU7L,=`S1>2-!`&)P@-5X(M%V(L`C00"+2H^G36)1=R#1=@$P47L
M'HM%W(G!P<$%BT7LBU7P,=`S1>B-!`&)P@-5Y(M%V(L`C00"+2H^G36)1>"#
M1=@$P47P'HM%X(G!P<$%BT7PBU7<,=`S1>R-!`&)P@-5Z(M%V(L`C00"+2H^
MG36)1>2#1=@$P47<'HM%Y(G!P<$%BT7<BU7@,=`S1?"-!`&)P@-5[(M%V(L`
MC00"+2H^G36)1>B#1=@$P47@'HM%Z(G!P<$%BT7@BU7D,=`S1=R-!`&)P@-5
M\(M%V(L`C00"+2H^G36)1>R#1=@$P47D'HM%[(G!P<$%BT7DBU7H,=`S1>"-
M!`&)P@-5W(M%V(L`C00"+2H^G36)1?"#1=@$P47H'HM%\(G!P<$%BT7HBU7L
M,=`S1>2-!`&)P@-5X(M%V(L`C00"+2H^G36)1=R#1=@$P47L'HM%W(G!P<$%
MBT7LBU7P,=`S1>B-!`&)P@-5Y(M%V(L`C00"+2H^G36)1>"#1=@$P47P'HM%
MX(G!P<$%BT7PBU7<,=`S1>R-!`&)P@-5Z(M%V(L`C00"+2H^G36)1>2#1=@$
MP47<'HM%Y(G!P<$%BT7<BU7@,=`S1?"-!`&)P@-5[(M%V(L`C00"+2H^G36)
M1>B#1=@$P47@'HM%Z(G!P<$%BT7@BU7D,=`S1=R-!`&)P@-5\(M%V(L`C00"
M+2H^G36)1>R#1=@$P47D'HM%[(G!P<$%BT7DBU7H,=`S1>"-!`&)P@-5W(M%
MV(L`C00"+2H^G36)1?"#1=@$P47H'HM%\(G!P<$%BT7HBU7L,=`S1>2-!`&)
MP@-5X(M%V(L`C00"+2H^G36)1=R#1=@$P47L'HM%"(L`B<(#5=R+10B)$(M%
M"(M`!(G"`U7PBT4(B5`$BT4(BT`(B<(#5>R+10B)4`B+10B+0`R)P@-5Z(M%
M"(E0#(M%"(M`$(G"`U7DBT4(B5`0@<1P`0``6UW#58GEBT4(QP`!(T5GBT4(
MQT`$B:O-[XM%",=`"/[<NIB+10C'0`QV5#(0BT4(QT`0\.'2PXM%",=`%```
M``"+10C'0!@`````BT4(QT!<`````%W#58GE@^P8BT4(BT`4BU40P>(#`=")
M1?"+10B+0!0[1?!V#XM%"(M`&(U0`8M%"(E0&(M%"(M5\(E0%(M%"(M`&(M5
M$,'J'8T4$(M%"(E0&(M%"(M`7(7`#X2I````BT4(BT!<ND````")T2G!B<B)
M1?2+1?0[11!^!HM%$(E%](M%](M5"(U*'(M5"(M27(T4$8/L!%#_=0Q2Z,#=
M__^#Q!"+1?0I11"+1?0!10R+10B+0%R)P@-5](M%"(E07(M%"(M`7(/X0'5G
M@^P,_W4(Z##L__^#Q!#K+8M%"(/`'(/L!&I`_W4,4.AQW?__@\00@T4,0(-M
M$$"#[`S_=0CH`>S__X/$$(-]$#]_S8M%$(M5"(/"'(/L!%#_=0Q2Z#S=__^#
MQ!"+10B+51")4%SK`9#)PU6)Y?]U#.C&Z___@\0$BT4,BP#!Z!B(PHM%"(@0
MBT4(C5`!BT4,BP#!Z!"(`HM%"(U0`HM%#(L`P>@(B`*+10B-4`.+10R+`(@"
MBT4(C5`$BT4,BT`$P>@8B`*+10B-4`6+10R+0`3!Z!"(`HM%"(U0!HM%#(M`
M!,'H"(@"BT4(C5`'BT4,BT`$B`*+10B-4`B+10R+0`C!Z!B(`HM%"(U0"8M%
M#(M`",'H$(@"BT4(C5`*BT4,BT`(P>@(B`*+10B-4`N+10R+0`B(`HM%"(U0
M#(M%#(M`#,'H&(@"BT4(C5`-BT4,BT`,P>@0B`*+10B-4`Z+10R+0`S!Z`B(
M`HM%"(U0#XM%#(M`#(@"BT4(C5`0BT4,BT`0P>@8B`*+10B-4!&+10R+0!#!
MZ!"(`HM%"(U0$HM%#(M`$,'H"(@"BT4(C5`3BT4,BT`0B`+)PU6)Y8/L&(M%
M#(M`%(E%](M%#(M`&(E%\(M%],'H`X/@/XE%[(M%#(U0'(M%[(T$`L8`@/]%
M[(-][#A^2;A`````*T7LBU4,C4H<BU7LC101@^P$4&H`4N@_VO__@\00@^P,
M_W4,Z!?J__^#Q!"+10R#P!R#[`1J.&H`4.@;VO__@\00ZR.X.````"M%[(M5
M#(U*'(M5[(T4$8/L!%!J`%+H]MG__X/$$(M%\,'H&(C"BT4,B%!4BT7PP>@0
MB,*+10R(4%6+1?#!Z`B(PHM%#(A05HM%\(C"BT4,B%!7BT7TP>@8B,*+10R(
M4%B+1?3!Z!"(PHM%#(A068M%],'H"(C"BT4,B%!:BT7TB,*+10R(4%N#[`C_
M=0S_=0CHD/W__X/$$,G#58GE@^P8QT7T`````,=%\`````#H_=K__X/L#%#H
MU-K__X/$$(E%\(-]\`!T"(M%\(L`B47TBT7TR<-5B>6#[`B#[`QJ`.AKW/__
M@\00BP"#[`Q0Z$W9__^#Q!"#[`Q0Z'';__^#Q!"#[`A0_W4(Z`(7``"#Q!"%
MP`^%AP```(/L#&H`Z"W<__^#Q!"+`(/L#%#H#]G__X/$$(/L#%#H,]O__X/$
M$(M`$"4`\```/0!```!T-H/L#&H`Z/?;__^#Q!"+`(/L#%#HV=C__X/$$(/L
M#%#H_=K__X/$$(M`$"4`\```/0"@``!U&X/L"&H"_W4(Z![9__^#Q!"%P'4'
MN`$```#K!;@`````R<-5B>575E.#[#S'1>``````QT7<`````(U5P+M$UP0(
MN`8```")UXG>B<'SI<=%V`````#'1>0`````Z<8```"#[`S_=>#H>][__X/$
M$(E%W(-]W`!T"8M%W(H`A,!U%H/L"/]U"/]UX.ARWO__@\00Z8T```"#[`C_
M=0C_==SHUMG__X/$$(7`=7B#[`S_=0CH--G__X/$$(G#H4A1!0B#[`Q0Z"'9
M__^#Q!`!PX/L#/]UW.@1V?__@\00C00#@\`"@^P,4.B?V?__@\00B478BQ5(
M404(N,G4!`B#[`S_==Q2_W4(4/]UV.A+UO__@\0@@^P(_W78_W7@Z.#=__^#
MQ!#_1>2+1>2+1(7`B47@BT7@B@"$P`^%(____XUE](/$`%M>7UW#58GE5U93
M@>P\@0``BT4(B87$?O__9:$4````B47D,<#'A3A___\`````QX4D?___````
M`,>%('___P````"-E>A^__^[L-8$"+@$````B=>)WHG!\Z6-E=!^__^[V-8$
M"+@&````B=>)WHG!\Z6-E?A^__^[`-<$"+@#````B=>)WHG!\Z7'A1Q___^>
MU00(QX48?___H]4$",>%-'___P````#'A3!___\`````QX44?___`````,>%
M$'___P````"#[`QHL=0$".C/W/__@\00B84@?___@[T@?___`'0SBX4@?___
MB@"$P'0G@^P,_[4@?___Z-[]__^#Q!"#[`S_M2!____H9MG__X/$$.D.!@``
MZ+/\__^)A3!___^#O3!___\`=7''A4!___\`````ZSV#[`S_M21____H7-S_
M_X/$$(F%('___X.]('___P!T%X/L#/^U('___^@0V?__@\00B84P?____X5`
M?___@[TP?___`'4?BX5`?___BX2%^'[__XF%)'___XN%)'___XH`A,!UFX.]
M,'___P!U#,>%,'___Z35!`CK3XN%,'___XF%/'___^LUZ&'6__^+$(N%/'__
M_XH`#[[``<"-!`)FBP`E__\``(/@"(7`=0F+A3Q____&`%__A3Q___^+A3Q_
M__^*`(3`=;_'A4!___\`````ZU*#[`S_M21____HA]O__X/$$(F%('___X.]
M('___P!T+(/L#/^U('___^C0^___@\00A<!T%X/L#/^U('___^@FV/__@\00
MB84X?____X5`?___@[TX?___`'4?BX5`?___BX2%T'[__XF%)'___XN%)'__
M_XH`A,!UAL>%0'___P````#K,H/L#/^U('___^AJ^___@\00A<!T%X/L#/^U
M('___^C`U___@\00B84X?____X5`?___@[TX?___`'4?BX5`?___BX2%Z'[_
M_XF%('___XN%('___XH`A,!UIH/L#/^U.'___^BKU?__@\00B<.#[`S_M1Q_
M___HF-7__X/$$`'#@^P,_[4P?___Z(75__^#Q!`!PX/L#/^U&'___^ARU?__
M@\00C00#!0`$``")A1!___^+A1!___^#[`Q0Z/+5__^#Q!")A11___^+%411
M!0BXJ]4$"(/L"/^U,'____^U''___U+_M3A___]0_[44?___Z(S2__^#Q""#
M[`AH[0$``/^U%'___^BFTO__@\00@^P,:+35!`CH\MG__X/$$(F%('___X.]
M('___P!T+H/L#/^U('___^BFUO__@\00B<*+A<1^__^+`(/L"%)0Z.3<__^#
MQ!")A31___^#O31___\`=0Z+A<1^__^+`(F%-'___^C-XO__A<`/A0@"``"#
M[`AJ`/^U-'___^@2UO__@\00B84,?___@[T,?___``^$X@$``&H":O]J[O^U
M#'___^B[TO__@\00@^P$:@:-A41___]0_[4,?___Z"'3__^#Q!"*A41___^$
MP`^%G@```(J%17___SQ##X60````BH5&?___/$$/A8(```"*A4=___\\0W5X
MBH5(?___/$AU;HJ%27___SQ%=61J`FK_:L;_M0Q____H1=+__X/$$(/L!&HI
MC85$?___4/^U#'___^BKTO__@\00BQ5$404(N+G5!`B#[`C_M1A___^-C41_
M__]14O^U%'___U#_M11____H"M'__X/$(.GE`0``@^P,C85$____4.BQ]/__
M@\00ZQ^#[`3_M0A___^-A41___]0C85$____4.CD]/__@\00@^P$:`"```"-
MA41___]0_[4,?___Z"72__^#Q!")A0A___^#O0A___\`?[6#[`S_M0Q____H
ME=/__X/$$(/L"(V%1/___U"-1=!0Z!3W__^#Q!#'A2Q___\`````ZS:-1=`#
MA2Q___^*`#'2B,*XR-4$"(N-+'___P')C5VGC0P+@^P$4E!1Z$/0__^#Q!#_
MA2Q___^#O2Q___\3?L'&1<\`BQ5$404(N+G5!`B#[`C_M1A___^-3:=14O^U
M%'___U#_M11____H`M#__X/$(.G=````QX4H?___`````(/L#/^U%'___^AR
MTO__@\00B84$?___@^P(:'C5!`AH[-0$".AMU___@\00Z-_/__^+#411!0BZ
MS=4$"(/L"/^U&'___U!1_[44?___4O^U%'___^B7S___@\0@ZTZ+A01___^+
ME11___^-!`+&``#_A2A____HE<___XL-1%$%"+K;U00(@^P$_[48?____[4H
M?___4%'_M11___]2_[44?___Z$?/__^#Q""#[`AH[0$``/^U%'___^AAS___
M@\00@_C_=0SH%,___XL`@_@1=(N#[`C_M11___]HL=0$".BPUO__@\00@^P,
M_[44?___Z,#W__^#Q!"+A11___^+5>1E,Q44````=`7H+]+__XUE](/$`%M>
M7UW#58GE4X/L=,=%]`````"#?0@`#X16`0``BT4(B@"$P`^$3`$``(/L#/]U
M".B4T/__@\00B47P@WWP``^%]0```.DM`0``BT7L@\`3@^P(:,?4!`A0Z`O3
M__^#Q!"%P`^$T0```(M%[(/`$X/L"&CLU00(4.CLTO__@\00A<`/A+(```"#
M[`S_=0CHUM#__X/$$(G#BT7L@\`3@^P,4.C"T/__@\00C00#@\`"B47HBT7H
M@^P,4.A*T?__@\00B47TBT7LC5`3N._5!`A2_W4(4/]U].C\S?__@\00BT7T
M@^P(C56(4E#HZ0P``(/$$(/X_W0?BT68)0#P```]`$```'40@^P,_W7TZ//^
M__^#Q!#K#H/L#/]U].A7T/__@\00@^P,_W7TZ$G/__^#Q!#'1?0`````@^P,
M_W7PZ/3/__^#Q!")1>R#?>P`#X7U_O__@^P,_W7PZ&G0__^#Q!"#[`S_=0CH
MR]#__X/$$.L$D.L!D(M=_,G#58GE@^P8@^P,_W4(Z/K:__^#Q!")1?2#[`S_
M=?3HK=K__X/$$(E%\.CSW?__A<!T-8-]"`!T+XM%"(H`A,!T)H/L"&B>U00(
M_W7PZ"W0__^#Q!`[1?!U#H/L#/]U".@F_O__@\00R<-5B>564X/L#&H`Z%;1
M__^#Q!"+`(/L#%#H.,[__X/$$(/L#%#HW,S__X/$$(L`BW`$@^P,:@#H*M'_
M_X/$$(L`@^P,4.@,SO__@\00@^P,4.A0S?__@\00B@`E_P```(G#@^-_@^P,
M:@#H]]#__X/$$(L`@^P,4.C9S?__@\00@^P,4.@MS?__@\00BP"+0!`E_P$`
M`"7__P``P>`'"=AFB48"@^P,:@#HN-#__X/$$(L`@^P,4.B:S?__@\00@^P,
M4.@^S/__@\00BP"+6`2#[`QJ`.B,T/__@\00BP"#[`Q0Z&[-__^#Q!"#[`1J
M`&BCU00(4.CKS___@\00B4,<@^P,:@#H6]#__X/$$(L`@^P,4.@]S?__@\00
M@^P,4.CAR___@\00BP"+6`2#[`QJ`.@OT/__@\00BP"#[`Q0Z!'-__^#Q!"#
M[`Q0Z#7,__^#Q!"+`(E#((/L#&H`Z`/0__^#Q!"+`(/L#%#HY<S__X/$$(/L
M#%#HB<O__X/$$(L`BU@$@^P,:@#HU\___X/$$(L`@^P,4.BYS/__@\00@^P,
M4.C-SO__@\00BP"%P'0N@^P,:@#HJL___X/$$(L`@^P,4.B,S/__@\00@^P,
M4.B@SO__@\00BP"+0&SK!;@`````B4,D@^P,:@#H=,___X/$$(L`@^P,4.A6
MS/__@\00@^P,4.CZRO__@\00BP"+0`3'0"@`````@^P,:@#H0<___X/$$(L`
M@^P,4.@CS/__@\00@^P,4.C'RO__@\00BP"+0`3'0!@`````@^P,:@#H#L__
M_X/$$(L`@^P,4.CPR___@\00@^P,4.B4RO__@\00BP"+6`2#[`QJ`.CBSO__
M@\00BP"#[`Q0Z,3+__^#Q!"#[`Q0Z(C.__^#Q!"+`(E#+(UE^(/$`%M>7<-5
MB>6#[`B#[`QJ`.BFSO__@\00BP"#[`Q0Z(C+__^#Q!"#[`AJ_U#HRLO__X/$
M$(/L#&H`Z'W.__^#Q!"+`(/L#%#H7\O__X/$$(/L!&H`:*O'!`A0Z*S.__^#
MQ!#)PU6)Y593@^P@QT7P`````(/L#&H`Z#[.__^#Q!"+`(/L#%#H(,O__X/$
M$(/L#%#HE,O__X/$$,8``8/L#&C0U`0(Z"W1__^#Q!")1>R#?>P`=!.+1>R*
M`#PQ=0J+1>Q`B@"$P'0%Z"38__^#[`QJ`.CCS?__@\00BP"#[`Q0Z,7*__^#
MQ!!J"VH!:/75!`A0Z'/*__^#Q!")1>B#?>@`#X0G`0``BT7HBT`,BT`8B47D
MQT7T`0```.FM````BT7TC5C_@^P,:@#HB\W__X/$$(L`@^P,4.AMRO__@\00
M:@!3_W7D4.C>R___@\00B47@@WW@``^$@````(M%X(L`BT`()0`$``"%P'0*
MBT7@BP"+0`SK+HM%X(L8@^P,:@#H-,W__X/$$(L`@^P,4.@6RO__@\00:@)J
M`%-0Z'C-__^#Q!"+%8Q1!0B+3?3!X0(!RHL2@^P(4%+H&\W__X/$$(7`=1G_
M1?#_1?2AB%$%"#E%]`^,1?___^L$D.L!D*&(404(2#M%\'5#QT7T`0```.LP
M@^P,:@#HO,S__X/$$(L`@^P,4.B>R?__@\00@^P(_W7D4.@_R?__@\00B47<
M_T7TH8A1!0@Y1?1\QH/L#&H`Z(+,__^#Q!"+`(/L#%#H9,G__X/$$&H$:@%H
M^M4$"%#H$LG__X/$$(E%Z(-]Z`!T>8M%Z(M`#(L8@^P,:@#H1,S__X/$$(L`
M@^P,4.@FR?__@\00@^P$:/S5!`A34.CTR/__@\00BT7HBT`,BP"+0`@E``!`
M`(7`=#"+1>B+0`R+&(/L#&H`Z/O+__^#Q!"+`(/L#%#HW<C__X/$$(/L"%-0
MZ+#*__^#Q!"#[`QJ`.C3R___@\00BP"#[`Q0Z+7(__^#Q!!J!&H!:`'6!`A0
MZ&/(__^#Q!")1>B#?>@`#X2-````QT78`````(/L#&BZU`0(Z*O.__^#Q!")
M1=B#?=@`=#6+1>B+0`R+&(/L#&H`Z''+__^#Q!"+`(/L#%#H4\C__X/$$(/L
M!/]UV%-0Z"/(__^#Q!#K.*&,404(BS"+1>B+0`R+&(/L#&H`Z#7+__^#Q!"+
M`(/L#%#H%\C__X/$$(/L!%934.B!S/__@\00@^P,:@#H#,O__X/$$(L`@^P,
M4.CNQ___@\00@^P,4.ABR/__@\00Q@``@^P,:@#HXLK__X/$$(L`@^P,4.C$
MQ___@\00@^P,4.CXRO__@\00QP``````@^P,:+'4!`CHSLW__X/$$*.$404(
MH811!0B%P`^%YP```*&,404(@^P,4.@-\/__@\00HX11!0B+'8Q1!0B+1>B+
M0`R+`(M`""4`!```A<!T#8M%Z(M`#(L`BT`,ZS&+1>B+0`R+,(/L#&H`Z$[*
M__^#Q!"+`(/L#%#H,,?__X/$$&H":@!64.B2RO__@\00@^P(4U#H-<C__X/$
M$(E%](M%Z(M`#(L`BT`()0`$``"%P'0-BT7HBT`,BP"+0`SK,8M%Z(M`#(L8
M@^P,:@#H[,G__X/$$(L`@^P,4.C.QO__@\00:@)J`%-0Z##*__^#Q!"+%8Q1
M!0B+$O]U]%!2:`36!`CH!LG__Z&$404(@^P(:.T!``!0Z&/%__^#Q!")1?2#
M??0`="B#??01="*#??3_=!R+%811!0BAC%$%"(L`_W7T4E!H--8$".B_R/__
MC67X@\0`6UY=PU6)Y8/L"(/L#&H`Z%7)__^#Q!"+`(/L#%#H-\;__X/$$(/L
M#%#H8\K__X/$$(/L#&H`Z"[)__^#Q!"+`(/L#%#H$,;__X/$$(/L"&H`:*/5
M!`AHH]4$"&BYR@0(:(+6!`A0Z,[&__^#Q"#)PXU,)`2#Y/#_<?Q5B>5348/L
M((G+@^P$C4,(4(U#!%")V%#HLLC__X/$$(/L!&@`E00(:`"5!`AHT)8$".B8
M`@``@\00@^P,:@#HR\7__X/$$(H`A,!U6.BMQ?__HX!1!0BA@%$%"(7`=0J#
M[`QJ`>C%R/__H8!1!0B#[`Q0Z%?&__^#Q!"#[`QJ`.AJR/__@\00BP"#[`Q0
MZ$S%__^#Q!"#[`Q0Z+#'__^#Q!#&``"#[`QJ`.A`R/__@\00BP"#[`Q0Z"+%
M__^#Q!"#[`Q0Z#;(__^#Q!"*$(/*`H@0@^P,:@#H$LC__X/$$(L`@^P,4.CT
MQ/__@\00@^P,4.@(R/__@\00BA"#R@&($(L#@\`%N@````")1>")5>3?;>#9
M[M[!W05@UP0(V<G:Z=_@]L1%#Y3`A,!T$H/L"&AD404(:)?6!`CH_\;__XL#
M@\`%P>`"@^P,4.@.Q___@\00HXQ1!0BAC%$%"(M3!(L2B1"AC%$%"(/`!,<`
MFM8$"*&,404(@\`(QP"@UP0(QP6(404(`P```*&,404(BQ6(404(P>("`=#'
M`)W6!`BAB%$%"$"CB%$%",=%\`$```#K)HL5C%$%"*&(404(`T7P2,'@`@'"
MBT,$BTWPP>$"`<B+`(D"_T7PBP,Y1?!\TZ&,404(BPN+%8A1!0B-%!%*P>("
M`=#'``````"+%8Q1!0B+"Z&(404(C00!C4C_H8!1!0B#[`QJ`%)1:*O/!`A0
MZ*?"__^#Q"")1?2#??0`=12A@%$%"(/L#%#H/</__X/$$(E%]*&`404(@^P,
M4.@YQ?__@\00@^P,:.#4!`CHI<G__X/$$(7`=3BAA%$%"(7`=16#[`QHL=0$
M".B(R?__@\00HX11!0BAA%$%"(7`=!&AA%$%"(/L#%#H@/3__X/$$*&`404(
M@^P,4.@,PO__@\00Z,3#__^+1?2-9?B#Q`!96UV-8?S#D)"0D%/H`````%N!
MP_Y\``"+@TP!``!0BTPD%%&+5"044HM$)!10Z&C"__^#Q!!;PY"0D%575E.#
M[!SH`````%N!P\A\``"+?"0PBVPD-.@0P?__C8/P_O__C9/P_O__*=#!^`*)
M1"0,="(Q]HVT)@````!2BT0D/%!55_^4L_#^__]&@\00.W0D#'+G@\0<6UY?
M7</K#9"0D)"0D)"0D)"0D)##D)"0D)"0D)"0D)"0D)"04^@`````6X'#3GP`
M`(M4)`Q2BT0D#%!J`^B"P?__@\0,6\.0D)"0D)"0D)"0D)"04^@`````6X'#
M'GP``(M4)`Q2BT0D#%!J`^ARPO__@\0,6\.0D)"0D)"0D)"0D)"058GE4X/L
M!*'D3@4(@_C_=!N[Y$X%"(UV`(V\)P````#_T(/K!(L#@_C_=?186UW#58GE
M4X/L!.@`````6X'#N'L``.AHQ?__65O)PP``````````````````````````
M`P````$``@!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R
M`"]P<F]C+W-E;&8O97AE`"\`.@`O<')O8R\E:2\E<P!E>&4`4$%27U1%35``
M4$%27U!23T=.04U%`"X`)7,E<R5S`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'0P!0
M05)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`
M4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!0
M05)?0TQ%04X]`#$```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(```<&%R+0``4UE35$5-`"5S)7,E<R5S`%!!5$@`)7,E<V-A8VAE+25S)7,`
M)3`R>``E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`+BX`)7,O)7,`
M05)'5@`8`'!E<FP`,```)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@+2!A
M8F]R=&EN9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@=&5M
M<&]R87)Y('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H
M("5I+@H`26YT97)N86QS.CI005(Z.D)/3U0`)7,`+64`+2T`0SI<5$5-4``O
M=&UP`````*#6!`BHU@0(Q]0$"*/5!`A435!$25(`5$5-4$1)4@!414U0`%1-
M4`!!U00(P-8$",?6!`C/U@0(U-8$"*/5!`A54T52`%5315).04U%````\-8$
M"/76!`BCU00(3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%265]0051(
M`$193$1?3$E"4D%265]0051(```,UP0('-<$""37!`BTU00(,=<$"*/5!`@`
M``````"`____ST$```````````````````````````````!P87(N<&P`````
M`````````````````````````````",A+W5S<B]B:6XO<&5R;`H*979A;"`G
M97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P
M87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO
M9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN
M92`Q-3D*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%
M3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z
M.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER
M92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I
M;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P
M=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP
M*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O
M<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P
M<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@
M4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@
M9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@
M;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@
M("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I
M;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE
M;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@
M8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@
M;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@
M("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@
M("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%
M35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&
M1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@
M("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@
M("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K
M"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M
M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO
M9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP
M+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L
M;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H
M<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*
M?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A
M<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N
M9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB
M4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@
M("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y
M<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%2
M1U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N
M9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z
M35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I
M8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U
M;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE
M('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N
M(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(
M*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A
M9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!
M4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L
M("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U
M9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG
M(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI
M<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@
M("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI
M.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD
M77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M
M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*
M("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D
M*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@
M("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D
M97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@
M("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D
M;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@
M("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@
M("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E
M(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M
M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@
M("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P
M96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@
M("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B
M=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN
M86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@
M("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^
M("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@
M<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L
M($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@
M("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@
M("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@
M("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H
M)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@
M(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN
M97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@
M("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@
M("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*
M("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T
M+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI
M.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN
M;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N
M86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@
M;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@
M('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@
M>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN
M9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V
M>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE
M<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO
M860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@
M(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-
M4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E
M(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@
M("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@
M("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T
M92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O
M("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE
M7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*
M"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S
M=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N
M="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@
M9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N
M<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@
M("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@
M("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R
M"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@;7D@0&%D9%]T
M;U]I;F,["B`@("!W:&EL92`H0$%21U8I('L*("`@("`@("`D05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@
M("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I
M;F,L("0R.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2![
M"B`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@?0H@("`@("`@
M(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@("`@=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T\G
M*2!["B`@("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("!]"B`@("`@("`@
M96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`D8G5N9&QE(#T@)W-I
M=&4G.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@
M("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("!]"B`@("`@("`@
M96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`D<75I970@/2`Q.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@
M("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T
M(&]P96X@;&]G.B`D(2(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E
M<2`G5"<I('L*("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@
M("!]"@H@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@(&1E;&5T92`D14Y6
M>R=005)?5$5-4"=].PH@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@
M("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@(&5X
M:70["B`@("`@("`@?0H@("`@?0H*("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*
M(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O
M=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@
M24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]
M"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*
M("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@
M)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@
M("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&
M:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@
M("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B
M4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`]
M(&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T
M<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F
M:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D
M:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@
M9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@
M(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@
M("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L
M"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=2
M3TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@
M("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H
M9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@
M<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^
M.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@
M+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N
M=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@
M)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]0
M05)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!
M4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@
M<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G
M("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G
M.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD
M968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[
M>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A
M=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@
M("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I
M.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T
M:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@
M("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H
M)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.
M0SL*"B`@("`@("`@:68@*"1#;VYF:6=[7V1E;&EM?2!E<2`G7%PG*2![('-[
M7%Q]>R]]9R!F;W(@0&EN8R!]"@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S
M="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO
M;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:
M;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I
M9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@
M("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@
M=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F
M86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@
M+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y
M<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*
M"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL
M92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@
M("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D
M<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D
M,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D
M("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@
M(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@
M("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@
M("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I
M9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X[
M"B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@
M("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U<"!A=71O
M+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\*("`@
M("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA33&]A9&5R
M+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I
M='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)
M3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F
M*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@
M("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H
M92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M
M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@
M('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^
M;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S
M=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2![
M"B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D
M9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?
M;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]
M"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M
M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN
M="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W
M-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E
M<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O
M9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T
M(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@
M("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@
M("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@
M("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D
M(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*
M("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@
M)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@
M("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@
M("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]
M"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO
M=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50
M871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y
M;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T
M<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,[
M"B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@
M("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,[
M"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@
M("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@
M("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV
M93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A
M=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@
M("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@
M4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O
M9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L
M<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N
M=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@
M("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@
M("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@
M("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED
M.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@
M(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I
M('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64[
M"B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@
M("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@
M("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6
M>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI
M6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA
M;64I.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@
M("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B
M=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@
M+34X+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q
M.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@
M("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D
M8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@
M("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@
M86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@
M("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D
M9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@
M('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@
M("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*
M("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@
M;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I
M.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N
M86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D
M9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N
M9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@
M(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM
M;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A
M;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G
M;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O
M9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD
M97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@
M("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%
M3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*
M("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E
M>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE
M?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@
M)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@
M)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF
M("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@
M("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@
M("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P
M=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D
M96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B![
M"B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@
M("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I
M("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@
M("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@
M("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE
M=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@
M)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@
M("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%2
M7T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N
M(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D
M;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@
M(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#
M;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI
M8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C
M=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S
M<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#`R
M"@I?7T5.1%]?"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/__
M__\`````_____P```````````0````$````!````M`(```$```"_`@```0``
M`,D"```!````&`,```$```!+!```#P```'$$```,````4)0$"`T````PU`0(
M]?[_;ZR!!`@%````-(H$"`8````$@P0("@```!8&```+````$````!4`````
M`````P```/1/!0@"````>`(``!0````1````%P```-B1!`@1````P)$$"!(`
M```8````$P````@```#^__]O,)$$"/___V\"````\/__;TJ0!`@`````````
M````````````````````````````````````````````````````````````
M^$X%"```````````EI0$"*:4!`BVE`0(QI0$"-:4!`CFE`0(]I0$"`:5!`@6
ME00()I4$"#:5!`A&E00(5I4$"&:5!`AVE00(AI4$"):5!`BFE00(MI4$",:5
M!`C6E00(YI4$"/:5!`@&E@0(%I8$"":6!`@VE@0(1I8$"%:6!`AFE@0(=I8$
M"(:6!`B6E@0(II8$"+:6!`C&E@0(UI8$".:6!`CVE@0(!I<$"!:7!`@FEP0(
M-I<$"$:7!`A6EP0(9I<$"':7!`B&EP0(EI<$"*:7!`BVEP0(QI<$"-:7!`CF
MEP0(]I<$"`:8!`@6F`0()I@$"#:8!`A&F`0(5I@$"&:8!`AVF`0(AI@$"):8
M!`BFF`0(MI@$",:8!`C6F`0(YI@$"/:8!`@&F00(%ID$"":9!`@VF00(1ID$
M"%:9!`AFF00(=ID$"```````````G=0$")_4!`C_____@-<$"&U9``!'0T,Z
M("A03$0M3&EN=7@I(#0N-2XP(#(P,3`P-3(S("AR96QE87-E*0!'0T,Z("A0
M3$0M3&EN=7@I(#0N-2XP(#(P,3`P-C`Q("AR96QE87-E*0``````'`````(`
M``````0``````("9!`@B```````````````A`````@!V````C0```'4```!?
M24]?<W1D:6Y?=7-E9```````<@````(```````0!`````("9!`BBF00(+BXO
M<WES9&5P<R]I,S@V+V5L9B]S=&%R="Y3`"]H;VUE+W5S97)S+V)U:6QD97(O
M<G!M+T)524Q$+V=L:6)C+3(N,3(O8W-U`$=.52!!4R`R+C(P+C4Q+C`N.``!
M@(D````"`!0````$`0`````!G0```#P```"DF00(I)D$"%L````"`0B/````
M`@(''P````($!X(````"!`=]`````@$&D0````("!3(````#!`5I;G0``@@%
MI`````((!W@````"!`6I````!`0'`@$&F`````5I`````1F'`````04#9-0$
M"`9/``````$1`!`&$0$2`0,(&P@E"!,%`````1$!)0X3"P,.&PX1`1(!$`8`
M``(D``L+/@L##@```R0`"PL^"P,(```$)``+"SX+```%-``##CH+.PM)$S\,
M`@H```8F`$D3````5P````(`,@````$!^PX-``$!`0$````!```!+BXO<WES
M9&5P<R]I,S@V+V5L9@``<W1A<G0N4P`!``````4"@)D$"`/```$S(30])2(#
M&"!96B$B7%L"`0`!`2,````"`!T````!`?L.#0`!`0$!`````0```0!I;FET
M+F,``````$=.52!#(#0N-2XP(#(P,3`P-3(S("AR96QE87-E*0!S:&]R="!U
M;G-I9VYE9"!I;G0`<VAO<G0@:6YT`"]H;VUE+W5S97)S+V)U:6QD97(O<G!M
M+T)524Q$+V=L:6)C+3(N,3(O8W-U`%])3U]S=&1I;E]U<V5D`&QO;F<@;&]N
M9R!U;G-I9VYE9"!I;G0`=6YS:6=N960@8VAA<@!I;FET+F,`;&]N9R!L;VYG
M(&EN=``.`````@!V````C0``````````+G-Y;71A8@`N<W1R=&%B`"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI
M8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`+F1E8G5G7V%R
M86YG97,`+F1E8G5G7W!U8FYA;65S`"YD96)U9U]I;F9O`"YD96)U9U]A8F)R
M978`+F1E8G5G7VQI;F4`+F1E8G5G7W-T<@`N9&5B=6=?<'5B='EP97,`````
M```````````````````````````````````````````````````;`````0``
M``(```!4@00(5`$``!,```````````````$`````````(P````<````"````
M:($$"&@!```@```````````````$`````````#$````'`````@```(B!!`B(
M`0``)```````````````!`````````!$````]O__;P(```"L@00(K`$``%@!
M```%``````````0````$````3@````L````"````!(,$"`0#```P!P``!@``
M``$````$````$````%8````#`````@```#2*!`@T"@``%@8`````````````
M`0````````!>````____;P(```!*D`0(2A```.8````%``````````(````"
M````:P```/[__V\"````,)$$"#`1``"0````!@````(````$`````````'H`
M```)`````@```,"1!`C`$0``&`````4`````````!`````@```"#````"0``
M``(```#8D00(V!$``'@"```%````#`````0````(````C`````$````&````
M4)0$"%`4```P```````````````$`````````(<````!````!@```("4!`B`
M%`````4`````````````!`````0```"2`````0````8```"`F00(@!D``+`Z
M`````````````!``````````F`````$````&````,-0$"#!4```<````````
M```````$`````````)X````!`````@```&#4!`A@5```KEP`````````````
M(`````````"F`````0````(````0,04($+$```0```````````````0`````
M````L`````$````#````Y$X%".2^```(```````````````$`````````+<`
M```!`````P```.Q.!0CLO@``"```````````````!`````````"^`````0``
M``,```#T3@4(]+X```0```````````````0`````````PP````8````#````
M^$X%"/B^``#X````!@`````````$````"````,P````!`````P```/!/!0CP
MOP``!```````````````!`````0```#1`````0````,```#T3P4(]+\``$@!
M``````````````0````$````V@````$````#````/%$%"#S!```<````````
M```````$`````````.`````(`````P```&!1!0A8P0``1!``````````````
M(`````````#E`````0```#``````````6,$``%0```````````````$````!
M````[@````$``````````````+#!```@```````````````(`````````/T`
M```!``````````````#0P0``)0```````````````0`````````-`0```0``
M````````````]<$```,!``````````````$`````````&0$```$`````````
M`````/C"``!?```````````````!`````````"<!```!``````````````!7
MPP``@@```````````````0`````````S`0```0```#``````````V<,``+(`
M``````````````$````!````/@$```$``````````````(O$```2````````
M```````!`````````!$````#``````````````"=Q```3@$`````````````
M`0`````````!`````@``````````````C,L``)`,```C````6`````0````0
M````"0````,``````````````!S8```3"@`````````````!````````````
M````````````````````````5($$"``````#``$``````&B!!`@``````P`"
M``````"(@00(``````,``P``````K($$"``````#``0```````2#!`@`````
M`P`%```````TB@0(``````,`!@``````2I`$"``````#``<``````#"1!`@`
M`````P`(``````#`D00(``````,`"0``````V)$$"``````#``H``````%"4
M!`@``````P`+``````"`E`0(``````,`#```````@)D$"``````#``T`````
M`##4!`@``````P`.``````!@U`0(``````,`#P``````$#$%"``````#`!``
M`````.1.!0@``````P`1``````#L3@4(``````,`$@``````]$X%"``````#
M`!,``````/A.!0@``````P`4``````#P3P4(``````,`%0``````]$\%"```
M```#`!8``````#Q1!0@``````P`7``````!@404(``````,`&```````````
M```````#`!D``````````````````P`:``````````````````,`&P``````
M```````````#`!P``````````````````P`=``````````````````,`'@``
M```````````````#`!\``````````````````P`@``$```````````````0`
M\?\(```````````````$`/'_$P``````````````!`#Q_QX```#D3@4(````
M``$`$0`L````[$X%"``````!`!(`.@```/1.!0@``````0`3`$<```"PF00(
M``````(`#0!=````>%$%"`$````!`!@`;````'Q1!0@$`````0`8`'H````0
MF@0(``````(`#0`3```````````````$`/'_A@```.A.!0@``````0`1`),`
M```0,04(``````$`$`"A````]$X%"``````!`!,`K0````#4!`@``````@`-
M``@```````````````0`\?_#```````````````$`/'_R@```(!1!0@$````
M`0`8`-(```"$404(!`````$`&`#:````B%$%"`0````!`!@`Z````(Q1!0@$
M`````0`8`/$```!XF@0(%@$```(`#0```0``1%$%"`0````!`!<`"`$``$A1
M!0@$`````0`7`!$!``".FP0(G@````(`#0`;`0``+)P$"!H````"``T`)@$`
M`$:<!`C"`0```@`-`#$!``"@804(!`````$`&``_`0``")X$"$4````"``T`
M3`$``*!1!0@`$````0`8`%@!``!,404(!`````$`%P!A`0``MJ4$"*@2```"
M``T`;P$``%ZX!`A4`````@`-`'@!``"RN`0(,P$```(`#0"#`0``Y;D$"%`!
M```"``T`F@$``#6[!`@E`0```@`-`*0!``"5O`0(T@````(`#0"R`0``1-<$
M"!@````!``\`O0$``+#6!`@0`````0`/`,@!``#8U@0(&`````$`#P#3`0``
M`-<$"`P````!``\`W@$``,S%!`AW`0```@`-`.L!``"KQP0(KP(```(`#0#Z
M`0``J\\$"&P````"``T`!@(`````````````!`#Q_Q("``#PT@0(+0````(`
M#0`C`@``]$\%"``````!`!8`.0(``*#3!`@C`````@`-`$`"``#0TP0((P``
M``(`#0!(`@``0%$%"``````!`!<`50(``/!.!0@``````0`2`&("``#PT@0(
M+0````(`#0!Q`@``Y$X%"````````!$`@@(``.1.!0@````````1`)4"``#X
M3@4(``````$`%`">`@``/%$%"``````@`!<`J0(`````````````$@```,4"
M``!(GP0(#0```!(`#0#6`@`````````````2````Z0(``!*B!`@\````$@`-
M`/8"`````````````!(````-`P`````````````2````'P,`````````````
M$@```#`#`````````````!(````Z`P``D-,$"`$````2``T`2@,``("9!`@`
M````$@`-`%$#`````````````!(```!<`P```)4$"``````2````;P,`````
M````````(````'X#`````````````"````"2`P``8-0$"`0````1``\`F0,`
M````````````$@```*P#`````````````!(```#``P`````````````2````
MU0,`````````````$@```.<#`````````````!(```#T`P``,-0$"``````2
M``X`^@,``+G*!`CR!```$@`-`!`$`````````````!(````C!```````````
M```2````0@0``&.E!`A3````$@`-`%`$``!-G@0(^P```!(`#0!F!```````
M```````2````>00`````````````$@```(($`````````````!(```"0!```
M```````````2````H`0`````````````$@```+($``!.H@0(^0```!(`#0"^
M!```6KP$"#L````2``T`V00`````````````$@```.<$``!#QP0(:````!(`
M#0#S!``````````````2````$`4`````````````$@```"\%````````````
M`!(````_!0``5%$%"`0````1`!<`3@4`````````````$@```%D%``"@UP0(
M;ED``!$`#P!C!0``9-0$"`0````1``\`<@4`````````````$@```(8%````
M`````````!(```"6!0`````````````2````I`4`````````````$@```+H%
M`````````````!(```#,!0``/%$%"``````0`!<`V04`````````````$@``
M`.L%`````````````!(```#^!0`````````````2````#`8`````````````
M$@```"4&``#`E@0(`````!(````U!@``T)8$"``````2````1@8`````````
M````$@```%<&`````````````!(```!F!@`````````````2````>P8`````
M````````$@```(T&`````````````!(```"?!@`````````````2````L08`
M````````````$@```,,&`````````````!(```#7!@``.)H$"$`````2``T`
MWP8`````````````$@```.X&```@TP0(80```!(`#0#^!@`````````````2
M````$`<``&!1!0@$````(0`8`",'`````````````!(````Q!P``````````
M```2````10<`````````````$@```%8'`````````````!(```!D!P``````
M```````2````=@<``%A1!0@`````$`#Q_X('`````````````!(```"4!P``
M```````````2````H`<`````````````$@```+P'`````````````!(```#-
M!P`````````````2````WP<`````````````$@```/`'`````````````!(`
M```""``````````````2````%@@`````````````$@```"D(``!:R@0(7P``
M`!(`#0!%"``````````````2````6@@`````````````$@```'@(``"D804(
M`````!``\?]]"``````````````2````D`@`````````````$@```)T(``!0
M404(!````!$`%P"L"```8%$%"`0````1`!@`P0@`````````````$@```-,(
M`````````````!(```#F"``````````````2````^`@`````````````$@``
M``H)``!D404($P```!$`&``9"0``CKX$"#X'```2``T`)@D``%A1!0@`````
M$`#Q_RT)`````````````!(````X"0``9[T$""<!```2``T`2@D``%6?!`B]
M`@``$@`-`%<)`````````````!(```!F"0`````````````2````>`D`````
M````````$@```(H)`````````````!(```"?"0`````````````2````L0D`
M````````````$@```,()`````````````!(```#2"0``1Z,$"!P"```2``T`
MWPD``!?0!`C5`@``$@`-`.0)``!0E`0(`````!(`"P#J"0`````````````2
M`````0H`````````````$@````!I;FET+F,`:6YI=&9I;FDN8P!C<G1S='5F
M9BYC`%]?0U1/4E],25-47U\`7U]$5$]27TQ)4U1?7P!?7TI#4E],25-47U\`
M7U]D;U]G;&]B86Q?9'1O<G-?875X`&-O;7!L971E9"XU-3(R`&1T;W)?:61X
M+C4U,C0`9G)A;65?9'5M;7D`7U]#5$]27T5.1%]?`%]?1E)!345?14Y$7U\`
M7U]*0U)?14Y$7U\`7U]D;U]G;&]B86Q?8W1O<G-?875X`&UA:6XN8P!M>5]P
M97)L`'-T;7!D:7(`;W!T:6]N<U]C;W5N=`!F86ME87)G=@!37W!R;V-S96QF
M7W9A;`!D:7)?<V5P`'!A=&A?<V5P`%]?9FEN9&5N=@!P87)?9V5T96YV`'!A
M<E]S971E;G8`86QL;V-E9"XQ-#4T-0!P87)?=6YS971E;G8`8FYA;64N,30V
M,34`<G8N,30V,S$`<VAA7W1R86YS9F]R;0!S:&%?:6YI=`!S:&%?=7!D871E
M`'-H85]T<F%N<V9O<FU?86YD7V-O<'D`<VAA7V9I;F%L`&ES5W)I=&%B;&5$
M:7(`0RXV-2XQ.3,S,0!#+C4V+C$Y,C,P`$,N-3<N,3DR,S$`0RXU."XQ.3(S
M,@!P87)?<FUT;7!D:7(`<&%R7W)E9&]?<W1A8VL`<&%R7WAS7VEN:70`;7E?
M<&%R7W!L+F,`7U]P=&AR96%D7V%T9F]R:P!?1TQ/0D%,7T]&1E-%5%]404),
M15\`<W1A=#8T`&QS=&%T-C0`7U]D<V]?:&%N9&QE`%]?1%1/4E]%3D1?7P!P
M=&AR96%D7V%T9F]R:P!?7VEN:71?87)R87E?96YD`%]?:6YI=%]A<G)A>5]S
M=&%R=`!?1%E.04U)0P!D871A7W-T87)T`%]?97)R;F]?;&]C871I;VY`0$=,
M24)#7S(N,`!P87)?8W5R<F5N=%]E>&5C`'-P<FEN=&9`0$=,24)#7S(N,`!P
M87)?8F%S96YA;64`4&5R;%])8W5R<W1A8VMI;F9O7W!T<@!G971P:61`0$=,
M24)#7S(N,`!M:V1I<D!`1TQ)0D-?,BXP`'!E<FQ?9G)E90!?7VQI8F-?8W-U
M7V9I;FD`7W-T87)T`'!E<FQ?<&%R<V4`4&5R;%]A=&9O<FM?=6YL;V-K`%]?
M9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`7V9P7VAW`')E86QL
M;V-`0$=,24)#7S(N,`!097)L7TEE=F%L7W)O;W1?<'1R`%]?>'-T870V-$!`
M1TQ)0D-?,BXR`%!E<FQ?26EN7V5V86Q?<'1R`%!E<FQ?26]P7W!T<@!?9FEN
M:0!84U]);G1E<FYA;'-?4$%27T)/3U0`<W1R;F-P>4!`1TQ)0D-?,BXP`%]?
M<F5G:7-T97)?871F;W)K0$!'3$E"0U\R+C,N,@!P87)?96YV7V-L96%N`'!A
M<E]C=7)R96YT7V5X96-?<')O8P!L<V5E:S8T0$!'3$E"0U\R+C(`<&5R;%]R
M=6X`4&5R;%]A=E]S:&EF=`!097)L7V=V7V9E=&-H<'8`;65M<V5T0$!'3$E"
M0U\R+C``<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`
M4&5R;%]S=E]S971P=@!P87)?8VQE86YU<`!?7VQI8F-?<W1A<G1?;6%I;D!`
M1TQ)0D-?,BXP`'!T:')E861?9V5T<W!E8VEF:6-`0$=,24)#7S(N,`!R96%D
M0$!'3$E"0U\R+C``<VEZ95]L;V%D7VUE7S(`<&5R;%]A;&QO8P!L;V%D7VUE
M7S(`7TE/7W-T9&EN7W5S960`4&5R;%]'9&]?=6YD=6UP7W!T<@!F<F5E0$!'
M3$E"0U\R+C``4&5R;%]D;W5N=VEN9`!?7VQX<W1A=#8T0$!'3$E"0U\R+C(`
M86-C97-S0$!'3$E"0U\R+C``7U]D871A7W-T87)T`%!E<FQ?271A:6YT961?
M<'1R`&]P96YD:7)`0$=,24)#7S(N,`!097)L7W-Y<U]T97)M`%]?8W1Y<&5?
M8E]L;V-`0$=,24)#7S(N,P!B;V]T7T1Y;F%,;V%D97(`4&5R;%]A=&9O<FM?
M;&]C:P!097)L7VYE=UA37V9L86=S`'!E<FQ?8V]N<W1R=6-T`')E861D:7(V
M-$!`1TQ)0D-?,BXR`&UE;6-P>4!`1TQ)0D-?,BXP`&5X96-V<$!`1TQ)0D-?
M,BXP`'-T<FQE;D!`1TQ)0D-?,BXP`'5N;&EN:T!`1TQ)0D-?,BXP`&=E='!W
M=6ED0$!'3$E"0U\R+C``>'-?:6YI=`!097)L7W-V7W-E='!V;@!?7VQI8F-?
M8W-U7VEN:70`9V5T=6ED0$!'3$E"0U\R+C``96YV:7)O;D!`1TQ)0D-?,BXP
M`%!E<FQ?879?9F5T8V@`8VQO<V5D:7)`0$=,24)#7S(N,`!C;&]S94!`1TQ)
M0D-?,BXP`'!E<FQ?9&5S=')U8W0`<W1R<W1R0$!'3$E"0U\R+C``7U]B<W-?
M<W1A<G0`;6%L;&]C0$!'3$E"0U\R+C``4&5R;%]M9U]S970`7U]S=&%C:U]C
M:&M?9F%I;$!`1TQ)0D-?,BXT`')M9&ER0$!'3$E"0U\R+C``<W1R=&]K0$!'
M3$E"0U\R+C``4&5R;%])<&%R<V5R7W!T<@!097)L7TES=&%T8G5F7W!T<@!R
M96%D;&EN:T!`1TQ)0D-?,BXP`&UE;6UO=F5`0$=,24)#7S(N,`!84U]);G1E
M<FYA;'-?4$%27T-,14%24U1!0TL`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R
M;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`7V5N9`!097)L7W-A9F5S>7-M
M86QL;V,`4&5R;%]N97=35G!V`&YA;65?;&]A9%]M95\R`%]?96YV:7)O;D!`
M1TQ)0D-?,BXP`&UE;6-H<D!`1TQ)0D-?,BXP`'-T<FYC;7!`0$=,24)#7S(N
M,`!O<&5N-C1`0$=,24)#7S(N,@!097)L7TET;W!?96YV7W!T<@!03%]M96UO
M<GE?=W)A<`!P87)?;6MT;7!D:7(`7V5D871A`%!E<FQ?;F5W6%,`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`%!E<FQ?<WES7VEN:70S`'-T<F1U
M<$!`1TQ)0D-?,BXP`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?265X:71?9FQA
M9W-?<'1R`'-T<F-M<$!`1TQ)0D-?,BXP`%!E<FQ?26-O;7!C=E]P='(`97AI
M=$!`1TQ)0D-?,BXP`'!A<E]I;FET7V5N=@!M86EN`%]I;FET`%!E<FQ?<V%V
A95]D97-T<G5C=&]R7W@`4&5R;%]S=E\R<'9?9FQA9W,`
